function AnalyzePICA(Index, RootDir, ElutionTimeRange)

exp_dir = ['SimulationSpectrum\', RootDir, '\exp',num2str(Index),'\'];


%% loading data
% load mz values
disp('Loading data.....');
mz_vector = load([exp_dir, 'mz_value.txt']);
% obtain the raw data list
raw_data_list = dir([exp_dir, 'data\*.txt']);
% scan number
scan_count = length(raw_data_list);
% load the peak mass
peak_mass = load([exp_dir, 'peak_mass.txt']);
% load retention center
lc_center = load([exp_dir, 'lc_center.txt']);


elution_last_scan = ElutionTimeRange;

%% begin to process
disp('Generate peak map');
peptide_count = size(peak_mass, 1);
esti_peptide_abundance = zeros(peptide_count, 1);
peak_map = sparse(scan_count, length(mz_vector));

for peptide_index=1:peptide_count
    pep_lc_center = lc_center(peptide_index);
    pep_peak = peak_mass(peptide_index, :);
    for peak_index=1:3
        abs_distance = abs(mz_vector - pep_peak(peak_index));
        pep_peak_index = find(abs_distance == min(abs_distance), 1, 'first');
        peak_map((pep_lc_center-elution_last_scan):(pep_lc_center+elution_last_scan), pep_peak_index) = 1;
    end
end
disp('load raw data');
% load raw data
total_raw_data = zeros(scan_count, length(mz_vector));
for raw_data_index = 1:scan_count
    total_raw_data(raw_data_index, :) = load([exp_dir, 'data\', num2str(raw_data_index), '.txt']);
end
disp('Processing ...');
for peptide_index=1:peptide_count
    pep_lc_center = lc_center(peptide_index);
    pep_peak = peak_mass(peptide_index, :);
    abs_distance = abs(mz_vector - pep_peak(1));
    start_index = find(abs_distance == min(abs_distance), 1, 'first');
    abs_distance = abs(mz_vector - pep_peak(3));
    end_index = find(abs_distance == min(abs_distance), 1, 'first');
    lc_distribution = [];
    for lc_center_index=(pep_lc_center-elution_last_scan):(pep_lc_center+elution_last_scan)
        raw_data = total_raw_data(lc_center_index, :);
        scan_peak_list = find(peak_map(lc_center_index,:) == 1);
        sel_peak_index = scan_peak_list(scan_peak_list>=start_index & scan_peak_list<=end_index);
        lc_distribution = [lc_distribution; sum(raw_data(sel_peak_index))];
    end
    lc_distribution = smooth(lc_distribution, 'sgolay');
    lc_peak_index = find(lc_distribution == max(lc_distribution), 1, 'first');
    lc_peptide_abundance = lc_distribution(lc_peak_index);
    highest_abundance = lc_peptide_abundance;
    left_index=lc_peak_index;
    right_index = lc_peak_index;
    while 1
        left_index = left_index - 1;
        right_index = right_index + 1;
        if left_index < 1 || right_index > length(lc_distribution)
            break;
        end
        lc_peptide_abundance = lc_peptide_abundance + lc_distribution(left_index) + lc_distribution(right_index);
        min_in = min(lc_distribution(left_index), lc_distribution(right_index));
        if min_in < 0.1 * highest_abundance
            break;
        end
    end
    esti_peptide_abundance(peptide_index) = lc_peptide_abundance;
end

file_writer = fopen([exp_dir, 'est_pica.txt'], 'w');
fprintf(file_writer, '%f\n', esti_peptide_abundance);
fclose(file_writer);