function AnalyzePepQuant(Index, RootDir, ElutionTimeRange)

exp_dir = ['SimulationSpectrum\', RootDir, '\exp',num2str(Index),'\'];
lamda = 0.5;
elution_last_scan = ElutionTimeRange;


%% loading data
% load mz values
mz_vector = load([exp_dir, 'mz_value.txt']);
% obtain the raw data list
raw_data_list = dir([exp_dir, 'data\*.txt']);
% scan number
scan_count = length(raw_data_list);
% load the peak mass
peak_mass = load([exp_dir, 'peak_mass.txt']);
% load retention center
lc_center = load([exp_dir, 'lc_center.txt']);
% load the peptide intensity
peak_intensity = load([exp_dir, 'peak_intensity.txt']);

%% begin to process
disp('Generate basis');
peptide_count = size(peak_mass, 1);
matrix_a = sparse(length(mz_vector), peptide_count);
for peptide_index=1:peptide_count
    pep_peak = peak_mass(peptide_index,:);
    for pep_peak_index=1:3
        pep_peak_value = pep_peak(pep_peak_index);
        abs_distance = abs(mz_vector - pep_peak_value);
        match_index = find(abs_distance == min(abs_distance), 1, 'first');
        matrix_a(match_index, peptide_index) = peak_intensity(peptide_index, pep_peak_index);
    end
end

A = [];
k = peptide_count;
m = scan_count;

zeros_index = (sum(matrix_a, 2) == 0);
matrix_a(zeros_index,:) = [];
n = length(mz_vector) - length(find(zeros_index == 1));

for i=1:m
    A = blkdiag(A, matrix_a);
end

disp('Generate constrain matrix');
region_constrain_matrix = sparse(k,m);
for i=1:k
    sel_peak_center = lc_center(i);
    region_constrain_matrix(i, (sel_peak_center-elution_last_scan):(sel_peak_center+elution_last_scan)) = 1;
end


clc;
region_constrain_matrix = reshape(region_constrain_matrix, 1, k * m);
non_zeros_index = (region_constrain_matrix == 1);

disp('Begin to solve the problem....');

row_i = 1:(k*m-k);
col_j = 1:(k * m -k);
s_value = ones(1, k*m-k);
row_i = [row_i 1:k*m-k];
col_j = [col_j col_j + k];
s_value = [s_value -1 * s_value];
D = sparse(row_i, col_j, s_value, k*m - k, k * m);

disp('Loading data');

y = zeros(n * m, 1);
for i=1:m
    tmp_buffer = load([exp_dir, 'data\', num2str(i), '.txt']);
    tmp_buffer(zeros_index) = [];
    y(((i-1) * n + 1):i*n) = tmp_buffer;
end

clear prob;
prob.cfix = 0.5 * y' * y;
[prob.qosubi, prob.qosubj , prob.qoval] = find(sparse(tril(A'*A)));
[prob.qcsubi,prob.qcsubj, prob.qcval] = find(sparse(tril(2 * D' * D)));
prob.qcsubk = ones(length(prob.qcsubi), 1);
prob.c = -A' * y;
prob.a = sparse(1, k * m);
prob.blc = [];
prob.buc = [];
prob.blx = sparse(k * m, 1);
upper_bound = sparse(k * m,1);
upper_bound(non_zeros_index) = inf;
prob.bux = upper_bound;
[r,res] = mosekopt('minimize',prob);

x=res.sol.itr.xx;
norm_constrain = x'*D'*D*x;

prob.buc = lamda * norm_constrain;
[r,res] = mosekopt('minimize',prob);

x = res.sol.itr.xx;
x=reshape(x, k, m);

disp('Saving analyze result.....');
for i=1:k
    disp(i);
    file_name = [exp_dir,'result\',num2str(i), '.txt'];
    fid = fopen(file_name,'w');
    fprintf(fid, '%f\n', x(i,:));
    fclose(fid);
end

est_pep_quant = zeros(peptide_count, 1);
for i=1:k
    sel_ab = x(i,:);
    lc_peak_index = find(sel_ab == max(sel_ab), 1, 'first');
    est_ab = sel_ab(lc_peak_index);
    highest_peak = sel_ab(lc_peak_index);
    right_index = lc_peak_index;
    left_index = lc_peak_index;
    while 1
        right_index = right_index + 1;
        left_index = left_index - 1;
        if left_index < 1 || right_index > length(sel_ab)
            break;
        end
        min_ab = min(sel_ab(left_index), sel_ab(right_index));
        if min_ab < 0.1 *  highest_peak
            break;
        end
        est_ab = est_ab + sel_ab(left_index) + sel_ab(right_index);
    end
    est_pep_quant(i) = est_ab;
end

fid = fopen([exp_dir, 'est_pepquant.txt'],'w');
fprintf(fid, '%f\n', est_pep_quant);
fclose(fid);