function [MassList, IntensityList]=EstimateIsotope(PeptideComposition, ChargeState, Limit)
% This is a function to get a theoretical distribution
% if the composition for a peptide is known

%% Create atom list and its corresponding count.
[atom_list, atom_count] = GetAtomInfor(PeptideComposition);
first_atom = 1;

%% Use convolution to get isotope distribution
for loop_index=1:length(atom_list)
    [atom_info_mass, atom_info_prob] = GetEleDistribution(atom_list(loop_index));
    for loop_index1=1:atom_count(loop_index)
        if first_atom == 1
            MassList = atom_info_mass;
            IntensityList = atom_info_prob;
            first_atom = 0;
        else
            [MassList, IntensityList] = CombineMass(MassList, IntensityList, atom_info_mass, atom_info_prob);
            if Limit == 0
                Limit = 1e-8;
            end
            limit_index = find(IntensityList <= Limit);
            MassList(limit_index) = [];
            IntensityList(limit_index) = [];
        end
    end
end

IntensityList = IntensityList / max(IntensityList) * 100;

%% Charge state
% electron_mass = 0.00054858;
H_mass = 1.0078246;
if ChargeState > 0
    MassList = (MassList + (ChargeState - 1) * H_mass) / ChargeState;
elseif ChargeState < 0
    MassList = (MassList + abs(ChargeState) * H_mass) / abs(ChargeState);
end