function GenerateSimulationData(Index, RootDir, ElutionTimeRange)

info_file = ['SimulationSpectrum\', RootDir,'\rand100_',num2str(Index),'_info.txt'];
seq_file = ['SimulationSpectrum\', RootDir, '\rand100_',num2str(Index),'_seq.txt'];
root_dir = ['SimulationSpectrum\', RootDir,'\exp',num2str(Index), '\'];
dir_name = ['SimulationSpectrum\',RootDir, '\exp',num2str(Index), '\data\'];
noise_factor = 20;


%% analyze mz range ,elution time range
info_content = load(info_file);
mz_min = min(info_content(:,2));
mz_max = max(info_content(:,2));
rt_min = min(info_content(:,1));
rt_max = max(info_content(:,1));
mz_interval = (mz_max-mz_min)/59000;
mz_vector = (mz_min-1):mz_interval:(mz_max + 1);
rt_interval = 1;
rt_begin = max(0, (rt_min - rt_interval * (ElutionTimeRange+20)));
rt_vector =  rt_begin: rt_interval : (rt_max + rt_interval * (ElutionTimeRange+20));
elution_last_scan = ElutionTimeRange;
%% Generate x

lc=0.5:(10-0.5)/(2 * elution_last_scan):10;
gaussian_value = exp(-0.3*(lc-5).^2);
peptide_count = size(info_content, 1);

% analyze peptide sequence file, analyze only the first three isotopes
file_reader = fopen(seq_file, 'r');
peptide_index = 1;
peptide_mass = zeros(peptide_count, 3);
peptide_intensity = zeros(peptide_count, 3);
while 1
    read_line = fgetl(file_reader);
    if ~ischar(read_line)
        break;
    end
    peptide_che = GeneratePeptide(read_line);
    charge_state = info_content(peptide_index, 4);
    [mass, intensity] = EstimateIsotope(peptide_che, charge_state, 0);
    for mass_index=1:3
        abs_distance = abs(mz_vector - mass(mass_index));
        match_index = find(abs_distance== min(abs_distance), 1, 'first');
        peptide_mass(peptide_index, mass_index) = mz_vector(match_index);
    end
    peptide_intensity(peptide_index, :) = intensity(1:3);
    peptide_index = peptide_index + 1;
end
fclose(file_reader);

lc_x = zeros(peptide_count, length(rt_vector));
% generate the groundtruth for PepQuant
pepquant_groundtruth = zeros(peptide_count, 1);
lc_center = zeros(peptide_count, 1);
% generate the groungtruth for PICA
pica_groundtruth = zeros(peptide_count, 1);
for peptide_index = 1:peptide_count
    % find the center of peptide
    lc_time = info_content(peptide_index, 1);
    abs_distance = abs(rt_vector - lc_time);
    lc_index = find(abs_distance == min(abs_distance), 1, 'first');
    lc_center(peptide_index) = lc_index;
    peak_height = info_content(peptide_index, 3);
    while peak_height > 100
        peak_height = peak_height / 10;
    end
    lc_begin = max(1, (lc_index-elution_last_scan));
    lc_x(peptide_index, lc_begin:(lc_index+elution_last_scan)) = peak_height * gaussian_value;
    pepquant_groundtruth(peptide_index) = peak_height * sum(gaussian_value(gaussian_value>=0.1));
    pica_groundtruth(peptide_index) = sum(peptide_intensity(peptide_index,:)) * peak_height * sum(gaussian_value(gaussian_value>=0.1));
end
save_file_name = 'PepQuant_groundtruth.txt';
file_writer = fopen([root_dir, save_file_name], 'w');
fprintf(file_writer, '%f\n', pepquant_groundtruth);
fclose(file_writer);
save_file_name = 'pica_groundtruth.txt';
file_writer = fopen([root_dir, save_file_name], 'w');
fprintf(file_writer, '%f\n', pica_groundtruth);
fclose(file_writer);
% save the mass
save_file_name = 'peak_mass.txt';
file_writer = fopen([root_dir, save_file_name], 'w');
fprintf(file_writer, '%f,%f,%f\n', peptide_mass');
fclose(file_writer);
% save the intensity
save_file_name = 'peak_intensity.txt';
file_writer = fopen([root_dir, save_file_name], 'w');
fprintf(file_writer, '%f,%f,%f\n', peptide_intensity');
fclose(file_writer);
%
save_file_name = 'lc_center.txt';
file_writer = fopen([root_dir, save_file_name], 'w');
fprintf(file_writer, '%d\n', lc_center);
fclose(file_writer);
%
save_file_name = 'mz_value.txt';
file_writer = fopen([root_dir, save_file_name], 'w');
fprintf(file_writer, '%f\n', mz_vector);
fclose(file_writer);

%% Generate matrix A
A = sparse(length(mz_vector), peptide_count);
for peptide_index=1:peptide_count
   tmp_buffer = zeros(1, length(mz_vector));
   for intensity_index=1:3
       tmp_buffer = tmp_buffer + peptide_intensity(peptide_index, intensity_index) *  exp(-1*500*(mz_vector - peptide_mass(peptide_index, intensity_index)).^2);
   end
   A(:, peptide_index) = tmp_buffer;
end

%% generate spectrum and save
for spectrum_index=1:length(rt_vector)
    spectrum_content = A * lc_x(:, spectrum_index) + noise_factor * randn(length(mz_vector), 1);
    zeros_index = (spectrum_content < 0);
    spectrum_content(zeros_index)  = 0;
    file_writer = fopen([dir_name, num2str(spectrum_index), '.txt'],'w');
    fprintf(file_writer, '%f\n', spectrum_content);
    fclose(file_writer);
end